
# Type: correlated with


holds between a disease or phenotypic feature and a measurable molecular entity that is used as an indicator of the presence or state of the disease or feature.

URI: [biolink:correlated_with](https://w3id.org/biolink/vocab/correlated_with)


## Domain and Range

[DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md) ->  <sub>0..*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [biomarker for](biomarker_for.md)
 *  [has biomarker](has_biomarker.md)

## Used by

 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [PhenotypicFeature](PhenotypicFeature.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002610 |
| **In Subsets:** | | translator_minimal |

